==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebGridKeydownEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridKeydownEventArgsDetailDescriptionMetadata } from "./WebGridKeydownEventArgsDetailDescriptionMetadata";
import { WebGridKeydownEventArgsDescription } from "./WebGridKeydownEventArgsDescription";
/**
 * @hidden
 */
export let WebGridKeydownEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridKeydownEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridKeydownEventArgsDescriptionMetadata.a == null) {
                WebGridKeydownEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridKeydownEventArgsDescriptionMetadata.c(WebGridKeydownEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebGridKeydownEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebGridKeydownEventArgsDescriptionMetadata.a);
            WebGridKeydownEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridKeydownEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebGridKeydownEventArgsDetail");
        }
        static d(a) {
            WebGridKeydownEventArgsDescriptionMetadata.b(a);
            a.ad("WebGridKeydownEventArgs", () => new WebGridKeydownEventArgsDescription());
            a.ac("WebGridKeydownEventArgs", WebGridKeydownEventArgsDescriptionMetadata.a);
        }
    }
    WebGridKeydownEventArgsDescriptionMetadata.$t = markType(WebGridKeydownEventArgsDescriptionMetadata, 'WebGridKeydownEventArgsDescriptionMetadata');
    WebGridKeydownEventArgsDescriptionMetadata.a = null;
    return WebGridKeydownEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebGridKeydownEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridKeydownEventArgsDetailDescriptionMetadata } from "./WebGridKeydownEventArgsDetailDescriptionMetadata";
import { WebGridKeydownEventArgsDescription } from "./WebGridKeydownEventArgsDescription";
/**
 * @hidden
 */
export let WebGridKeydownEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridKeydownEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridKeydownEventArgsDescriptionMetadata.a == null) {
                WebGridKeydownEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridKeydownEventArgsDescriptionMetadata.c(WebGridKeydownEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebGridKeydownEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebGridKeydownEventArgsDescriptionMetadata.a);
            WebGridKeydownEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridKeydownEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebGridKeydownEventArgsDetail");
        }
        static d(a) {
            WebGridKeydownEventArgsDescriptionMetadata.b(a);
            a.ae("WebGridKeydownEventArgs", () => new WebGridKeydownEventArgsDescription());
            a.ad("WebGridKeydownEventArgs", WebGridKeydownEventArgsDescriptionMetadata.a);
        }
    }
    WebGridKeydownEventArgsDescriptionMetadata.$t = markType(WebGridKeydownEventArgsDescriptionMetadata, 'WebGridKeydownEventArgsDescriptionMetadata');
    WebGridKeydownEventArgsDescriptionMetadata.a = null;
    return WebGridKeydownEventArgsDescriptionMetadata;
})();
